==> digikam-3.0.0-beta1.tar.bz2: digikam-3.0.0-beta1/extra/kipi-plugins/calendar/plugin/kipiplugin_calendar.desktop.cmake <==
[Desktop Entry]
Name=Calendar
Name[ast]=Calendariu
Name[bg]=Календар
Name[bs]=Kalendar
Name[ca]=Calendar
Name[ca@valencia]=Calendar
Name[cs]=Kalendář
Name[da]=Calendar
Name[de]=Kalender
Name[el]=Ημερολόγιο
Name[en_GB]=Calendar
Name[eo]=Kalendaro
Name[es]=Calendario
Name[et]=Kalender
Name[eu]=Egutegia
Name[fi]=Kalenteri
Name[fr]=Calendrier
Name[ga]=Féilire
Name[gl]=Calendario
Name[he]=לוח שנה
Name[hne]=कलेन्डर
Name[hr]=Kalendar
Name[hu]=Naptár
Name[is]=Dagatal
Name[it]=Calendario
Name[ja]=カレンダー
Name[km]=ប្រតិទិន
Name[lv]=Kalendārs
Name[mai]=कैलेंडर
Name[nb]=Kalender
Name[nds]=Kalenner
Name[nl]=Kalender
Name[pa]=ਕੈਲੰਡਰ
Name[pl]=Kalendarz
Name[pt]=Calendário
Name[pt_BR]=Calendário
Name[ro]=Calendar
Name[ru]=Календарь
Name[sk]=Kalendár
Name[sl]=Koledar
Name[sq]=Kalendari
Name[sv]=Kalender
Name[th]=ปฏิทิน
Name[tr]=Takvim
Name[ug]=يىلنامە
Name[uk]=Календар
Name[x-test]=xxCalendarxx
Name[zh_CN]=日历
Name[zh_TW]=月曆
Comment=A tool to create calendars
Comment[ast]=Una ferramienta pa criar calendarios
Comment[bg]=Инструмент за създаване на календари
Comment[bs]=Alat za kreiranje kalendara
Comment[ca]=Una eina per a crear calendaris
Comment[ca@valencia]=Una eina per a crear calendaris
Comment[cs]=Nástroj pro vytváření kalendářů
Comment[da]=Et værktøj til at oprette kalendere
Comment[de]=Ein Werkzeug, um Kalender zu erstellen.
Comment[el]=Εργαλείο δημιουργίας ημερολογίων
Comment[en_GB]=A tool to create calendars
Comment[es]=Una herramienta para crear calendarios
Comment[et]=Tööriist kalendri loomiseks
Comment[eu]=Egutegiak sortzeko tresna
Comment[fi]=Työkalu, jolla voi luoda kalentereita
Comment[fr]=Outil pour créer des calendriers
Comment[gl]=Unha ferramenta para crear calendarios
Comment[he]=כלי ליצירת לוחות שנה
Comment[hne]=कलेन्डर बनाय के एक औजार
Comment[hu]=Egy eszköz naptárak létrehozásához
Comment[is]=Verkfæri til að búa til dagatöl
Comment[it]=Uno strumento per creare calendari
Comment[ja]=カレンダーを作成するツール
Comment[km]=ឧបករណ៍​ត្រូវ​បង្កើត​ប្រតិទិន
Comment[lv]=Rīks kalendāru izveidošanai
Comment[nb]=Et verktøy for å lage kalendere
Comment[nds]=En Warktüüch, mit dat sik Kalenners opstellen laat
Comment[nl]=Een hulpmiddel om kalenders aan te maken
Comment[pa]=ਕੈਲੰਡਰ ਬਣਾਉਣ ਵਾਲਾ ਇੱਕ ਟੂਲ
Comment[pl]=Narzędzie do tworzenia kalendarzy
Comment[pt]=Uma ferramenta para criar calendários
Comment[pt_BR]=Uma ferramenta para criar calendários
Comment[ro]=O unealtă de creat calendare
Comment[ru]=Инструмент для создания календарей
Comment[sk]=Nástroj na vytvorenie kalendárov
Comment[sl]=Orodje za ustvarjanje koledarjev
Comment[sq]=Një mjet për të krijuar kalendarë
Comment[sv]=Ett verktyg för att skapa kalendrar
Comment[th]=เครื่องมือสร้างปฏิทินแบบต่าง ๆ
Comment[tr]=Takvim oluşturmak için bir araç
Comment[uk]=Інструмент для створення календарів
Comment[x-test]=xxA tool to create calendarsxx
Comment[zh_CN]=一个创建日历的工具
Comment[zh_TW]=製作月曆工具
Type=Service
Icon=view-pim-calendar
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_calendar
X-KIPI-MergeMenu=false
X-KIPI-PluginCategories=Tools
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Orgad Shaneh, orgads at gmail dot com

==> digikam-3.2.0-beta1.tar.bz2: digikam-3.2.0-beta1/extra/kipi-plugins/calendar/plugin/kipiplugin_calendar.desktop.cmake <==
[Desktop Entry]
UntranslatedGenericName=Calendar
Name=Calendar
Name[ast]=Calendariu
Name[bg]=Календар
Name[bs]=Kalendar
Name[ca]=Calendar
Name[ca@valencia]=Calendar
Name[cs]=Kalendář
Name[da]=Calendar
Name[de]=Kalender
Name[el]=Ημερολόγιο
Name[en_GB]=Calendar
Name[eo]=Kalendaro
Name[es]=Calendario
Name[et]=Kalender
Name[eu]=Egutegia
Name[fi]=Kalenteri
Name[fr]=Calendrier
Name[ga]=Féilire
Name[gl]=Calendario
Name[he]=לוח שנה
Name[hne]=कलेन्डर
Name[hr]=Kalendar
Name[hu]=Naptár
Name[is]=Dagatal
Name[it]=Calendario
Name[ja]=カレンダー
Name[km]=ប្រតិទិន
Name[lv]=Kalendārs
Name[mai]=कैलेंडर
Name[mr]=दिनदर्शिका
Name[nb]=Kalender
Name[nds]=Kalenner
Name[nl]=Kalender
Name[pa]=ਕੈਲੰਡਰ
Name[pl]=Kalendarz
Name[pt]=Calendário
Name[pt_BR]=Calendário
Name[ro]=Calendar
Name[ru]=Календарь
Name[sk]=Kalendár
Name[sl]=Koledar
Name[sq]=Kalendari
Name[sv]=Kalender
Name[th]=ปฏิทิน
Name[tr]=Takvim
Name[ug]=يىلنامە
Name[uk]=Календар
Name[x-test]=xxCalendarxx
Name[zh_CN]=日历
Name[zh_TW]=月曆
Comment=A tool to create calendars
Comment[ast]=Una ferramienta pa crear calendarios
Comment[bg]=Инструмент за създаване на календари
Comment[bs]=Alat za kreiranje kalendara
Comment[ca]=Una eina per a crear calendaris
Comment[ca@valencia]=Una eina per a crear calendaris
Comment[cs]=Nástroj pro vytváření kalendářů
Comment[da]=Et værktøj til at oprette kalendere
Comment[de]=Ein Werkzeug, um Kalender zu erstellen.
Comment[el]=Εργαλείο δημιουργίας ημερολογίων
Comment[en_GB]=A tool to create calendars
Comment[es]=Una herramienta para crear calendarios
Comment[et]=Tööriist kalendri loomiseks
Comment[eu]=Egutegiak sortzeko tresna
Comment[fi]=Työkalu, jolla voi luoda kalentereita
Comment[fr]=Outil pour créer des calendriers
Comment[gl]=Unha ferramenta para crear calendarios
Comment[he]=כלי ליצירת לוחות שנה
Comment[hne]=कलेन्डर बनाय के एक औजार
Comment[hu]=Egy eszköz naptárak létrehozásához
Comment[is]=Verkfæri til að búa til dagatöl
Comment[it]=Uno strumento per creare calendari
Comment[ja]=カレンダーを作成するツール
Comment[km]=ឧបករណ៍​ត្រូវ​បង្កើត​ប្រតិទិន
Comment[lv]=Rīks kalendāru izveidošanai
Comment[nb]=Et verktøy for å lage kalendere
Comment[nds]=En Warktüüch, mit dat sik Kalenners opstellen laat
Comment[nl]=Een hulpmiddel om kalenders aan te maken
Comment[pa]=ਕੈਲੰਡਰ ਬਣਾਉਣ ਵਾਲਾ ਇੱਕ ਟੂਲ
Comment[pl]=Narzędzie do tworzenia kalendarzy
Comment[pt]=Uma ferramenta para criar calendários
Comment[pt_BR]=Uma ferramenta para criar calendários
Comment[ro]=O unealtă de creat calendare
Comment[ru]=Инструмент для создания календарей
Comment[sk]=Nástroj na vytvorenie kalendárov
Comment[sl]=Orodje za ustvarjanje koledarjev
Comment[sq]=Një mjet për të krijuar kalendarë
Comment[sv]=Ett verktyg för att skapa kalendrar
Comment[th]=เครื่องมือสร้างปฏิทินแบบต่าง ๆ
Comment[tr]=Takvim oluşturmak için bir araç
Comment[uk]=Інструмент для створення календарів
Comment[x-test]=xxA tool to create calendarsxx
Comment[zh_CN]=一个创建日历的工具
Comment[zh_TW]=製作月曆工具
Type=Service
Icon=view-pim-calendar
ServiceTypes=KIPI/Plugin
X-KDE-Library=kipiplugin_calendar
X-KIPI-MergeMenu=false
X-KIPI-PluginCategories=Tools
X-KIPI-BinaryVersion=${KIPI_SO_VERSION}
author=Orgad Shaneh, orgads at gmail dot com
